##########################
KeyboardButtonPollTypeType
##########################


.. automodule:: litegram.enums.keyboard_button_poll_type_type
    :members:
    :member-order: bysource
    :undoc-members: True
